@@ -1,4 +1,3 @@
-
 """
 vbinds - This package's command-line entry-point application.
 """
@@ -15,7 +14,7 @@ from vbinds.classes.playable_class import get_classes
 
 
 def entry(args: argparse.Namespace) -> int:
-    """ Execute the requested task. """
+    """Execute the requested task."""
 
     args.out_dir = os.path.abspath(args.out_dir)
 
@@ -28,8 +27,7 @@ def entry(args: argparse.Namespace) -> int:
 
     classes = get_classes(engine)
     for class_name, data in classes.items():
-        filename = os.path.join(args.out_dir,
-                                (class_name + ".json").replace(" ", "_"))
+        filename = os.path.join(args.out_dir, class_name + ".json")
         with open(filename, "w") as outfile:
             indent = None if not args.indent else args.indent
             outfile.write(json.dumps(data.to_serialize, indent=indent))
@@ -40,9 +38,18 @@ def entry(args: argparse.Namespace) -> int:
 
 
 def add_app_args(parser: argparse.ArgumentParser) -> None:
-    """ Add application-specific arguments to the command-line parser. """
+    """Add application-specific arguments to the command-line parser."""
 
-    parser.add_argument("-o", "--out-dir", default=os.getcwd(),
-                        help="root directory for program outputs")
-    parser.add_argument("-i", "--indent", default=0, type=int,
-                        help="indent argument for json serialization")
+    parser.add_argument(
+        "-o",
+        "--out-dir",
+        default=os.getcwd(),
+        help="root directory for program outputs",
+    )
+    parser.add_argument(
+        "-i",
+        "--indent",
+        default=0,
+        type=int,
+        help="indent argument for json serialization",
+    )
