@@ -1,4 +1,3 @@
-
 """
 vbinds - A query extension for querying class data.
 """
@@ -11,10 +10,10 @@ from .query_engine import QueryEngine
 
 
 class ClassDataEngine(QueryEngine):
-    """ Exposes 'Playable Class API' queries. """
+    """Exposes 'Playable Class API' queries."""
 
     def get_classes(self, should_print: bool = False) -> Optional[dict]:
-        """ Exposes the 'Playable Class Index' API call. """
+        """Exposes the 'Playable Class Index' API call."""
 
         result = self.static_query("playable-class/index", False)
         if result is not None:
@@ -23,16 +22,19 @@ class ClassDataEngine(QueryEngine):
                 self.printer.pprint(result)
         return result
 
-    def get_class(self, class_id: int,
-                  should_print: bool = False) -> Optional[dict]:
-        """ Exposes the 'Playable Class' API call. """
+    def get_class(
+        self, class_id: int, should_print: bool = False
+    ) -> Optional[dict]:
+        """Exposes the 'Playable Class' API call."""
 
-        return self.static_query("playable-class/{}".format(str(class_id)),
-                                 should_print)
+        return self.static_query(
+            "playable-class/{}".format(str(class_id)), should_print
+        )
 
-    def get_class_media(self, class_id: int,
-                        should_print: bool = False) -> Optional[dict]:
-        """ Exposes the 'Playable Class Media' API call. """
+    def get_class_media(
+        self, class_id: int, should_print: bool = False
+    ) -> Optional[dict]:
+        """Exposes the 'Playable Class Media' API call."""
 
         q_str = "media/playable-class/{}".format(str(class_id))
         return self.static_query(q_str, should_print)
@@ -40,7 +42,7 @@ class ClassDataEngine(QueryEngine):
     def get_class_pvp_talent_slots(
         self, class_id: int, should_print: bool = False
     ) -> Optional[dict]:
-        """ Exposes the 'PvP Talent Slots' API call. """
+        """Exposes the 'PvP Talent Slots' API call."""
 
         q_str = "playable-class/{}/pvp-talent-slots".format(str(class_id))
         return self.static_query(q_str, should_print)
